import { AggregateState, Aggregate, Event, EventResolver } from "./interfaces";
/**
 * Use this function to build your aggregate instances.
 * @param state The current state of you aggregate
 * @param resolver The EventResolver your aggregate will use to mutate the state.
 * @returns This function will return an new aggregate instance.
 * @example
 * ```typescript
 * export function createCounter(
 *   commandId: string,
 *   state?: CounterState
 * ): Counter {
 *   const initialState: CounterState = {
 *     id: "none",
 *     count: 0,
 *     sequence: 0,
 *     commandId: commandId,
 *   };
 *
 *   if (state) {
 *     state.commandId = commandId;
 *   }
 *
 *   const currentState = state || initialState;
 *
 *   const aggregate = buildAggregate(currentState, counterEventResolver);
 *
 *   return {
 *     init: buildInit(aggregate),
 *     count: buildCount(aggregate),
 *     reset: buildReset(aggregate),
 *     ...aggregate,
 *   };
 * }
 * ```
 */
export declare function buildAggregate<S extends AggregateState, E extends Event>(state: S, resolver: EventResolver<S, E>, options?: {
    /**
     * This option will generate a snapshots every X events added.
     */
    snapshotEvery?: number;
}): Aggregate<S, E>;
